clear all; %clc
run 'C:\tomlab\startup';

% This file computes the results for alternative values of the tuning parameter alpha. 
% In the objective function of the optimization problem, the stability indices always get weight 1 and
% in this file we vary the weight of the deviations from profit efficiency, from 1000000 to 100.
% Note that the tuning parameter alpha = 1/(1+weight deviations profit efficiency).

weight_grid=[1000000 100000 10000 1000 100];
load MatchingData_annual_weak_c.txt

% De kolommen bevatten de volgende informatie: 
% MO1: dat nonlaborincome een consumption based measure is, wat de negatieve getallen verklaart.
% MO2: 1=male, 2 =female.
% (1) leisure_w; (2) leisure_m; (3) domlab_w; (4) domlab_m; (5) rexp_private_woman; (6) rexp_private_man; 
% (7) rexp_private_nonass; (8) rexp_public; (9) rexpagg (total annual real consumption); (10) land_w; (11) land_m; (12) land_hh; (13) land rented; (14) other_input; 
% (15) dom_output; (16) region (1: north, 2: central; 3: south); (17) district (+/- 30 in total); 
% (18) hhsize; (19) ea_id (villageID);  (20) estimated value of land owned by female; (21) estimated value of land owned by male; 
% (22) estimated rented per acre (for 12 months); (23) median wage female in district; (24) median wage male in district; 
% (25) month of interview;  (26) land owned jointly by male and female; (27) other_land (disappears after divorce).

Data=MatchingData_annual_weak_c;

%Data=Data(1:100,:);

size(Data);

%number of households
nobs=size(Data,1)

Data=Data(1:nobs,:);

rexpagg=Data(:,9);
hhsize=Data(:,18);
village=Data(:,19);

% define time available
T_male=6120; % maximum time available (for market work, domestic work or leisure), male
T_female=4032; % maximum time available (for market work, domestic work or leisure), female


% identify number of villages en number of households per village
villagenumber=1; % village umber will identify the number of different villages
villageid=village(1,1); %initialize village-id
for i=1:nobs
    if village(i,1) ~= villageid
        villagenumber=villagenumber+1;
        villageid=village(i,1);
    end
end

villagenumber

Data =[Data zeros(nobs,1)]; %add row for villageid
newcolnr=size(Data,2);

obspervillage=zeros(villagenumber,1); % obspervillage will contain num ber of households per village
idpervillage=zeros(villagenumber,3);


k=1; %begin with row 1 for first village
villageid=village(1,1);
for i=1:nobs
    if village(i,1) == villageid
        obspervillage(k,1)=obspervillage(k,1)+1;
        idpervillage(k,1)=k;
        idpervillage(k,2)=village(i,1);
        Data(i,newcolnr)=k;
    else
        k=k+1;
        villageid=village(i,1);
        obspervillage(k,1)=obspervillage(k,1)+1;
        Data(i,newcolnr)=k;
    end
end
idpervillage(:,3)=obspervillage;

% Save matrix with village IDs
resultpath='results - 2019 - tomlab - robustness weights';
filename_results1=['MALAWI_villageID_matrix.txt'];
fullfilename_results1=fullfile(resultpath,filename_results1);
dlmwrite(fullfilename_results1, idpervillage, 'delimiter', '\t', 'newline', 'pc');

%% Sensitivity analysis weights in objective function

for a = 1: size(weight_grid,2)
%% initilize result matrices
results_IR_index= zeros(0,2); % initialize resultmatrix IR
results_NBP_index= zeros(0,2); % define resultmatrixNBP
results_Profit_index= zeros(0,2); % define resultmatrix Profit Inefficiency
results_NBP_index_summary=zeros(0,3); % define resultmatrix NBP summary (3 columns: max, average and village)
results_NBP_index_male_summary=zeros(0,3); % define resultmatrix NBP summary (3 columns: max, average and village)
results_NBP_index_female_summary=zeros(0,3); % define resultmatrix NBP summary (3 columns: max, average and village)
results_IR_index_summary=zeros(0,3); % define resultmatrix IR summary (3 columns: male, female and village)
results_Profit_index_summary=zeros(0,2); % define resultmatrix Profit summary (2 columns: profit inefficiency and village)
results_Wages= zeros(0,3); % initialize resultmatrix Wages (3 columns: wage male, wage female and village)
results_LandPrice= zeros(0,2); % initialize resultmatrix Land Price (2 columns: land price and village)
results_LandInc= zeros(0,3); % initialize resultmatrix Land Income (3 columns: land income male, land income male and village)
results_ResNonLabInc= zeros(0,3); % initialize resultmatrix Residual nonlabor income(RNLI) (3 columns: RNLI male, RNLI female and village)
results_Incomeshares= zeros(0,3); % initialize resultmatrix Income Shares (3 columns: income share male, income share female and village)
obs_total=0

endrows=0

%% analysis per village

for k=1:villagenumber
k
nobs=obspervillage(k,1);
beginrows=endrows+1;
endrows=endrows+nobs;
Dataselect=Data(beginrows:endrows,:);

%define data entries for selected village
leisure1=Dataselect(:,2); 
leisure2=Dataselect(:,1); 
domlab1=Dataselect(:,4); 
domlab2=Dataselect(:,3);
q1=Dataselect(:,6);
q2=Dataselect(:,5); 
q3=Dataselect(:,7); %nonassignable private
Q=Dataselect(:,8); 
rexpagg=Dataselect(:,9);
land_1=Dataselect(:,11);
land_2=Dataselect(:,10);
land_hh_other=Dataselect(:,26);
other_land=Dataselect(:,27);
land_rent=Dataselect(:,13);
other_input=Dataselect(:,14);
output=Dataselect(:,15);
maxwagemale=2*Dataselect(:,24);
minwagemale=0*Dataselect(:,24);
maxwagefemale=2*Dataselect(:,23);
minwagefemale=0*Dataselect(:,23);
maxpriceland=2*Dataselect(:,22);
minpriceland=0*Dataselect(:,22);


% quantities total land
land_owned=land_1+land_2+land_hh_other;
land=land_owned+land_rent;

% total quantity vector (week)
qpriv=q1+q2+q3;
        
% USER INPUT
M=size(qpriv,1) % Nr of households (man/women) (possible pairs = M*M)
filename_passvector='results_matching.txt';
                      
%% linprog(f,A,b) solves min f'*x s.t. A*x<=b, Aeq*x=beq => define f, A, b, Aeq and beq
% for each couple (m,w): M*M*4 + M + 8*M + M*M + 2*M + M (= columns of matrix A and vector f)
    %(i.e. (1; for all M*M pairs) for the private expenditures: male and female quantities; (2; for all M*M pairs) for the public expenditures:
    % male and female prices prices); (3; for M matched pairs) price of land; (4; for M matched pairs: 8 (=4*2) components) first wage of male and female (1-2), 
    % then post-divorce land of male and female (3-4), (residual) nonlabor
    % income of male and female (5-6) and, finally, income share of male
    % and female (7-8)
    % (5) M*M (for each couple) and 2*M (for each individual: M males + M
    % females) goodness-of-fit measures; 
    % (6) M (pi-) + M*M + M (pi+) deviational variables for the profit efficiency constraints (M eq, M*M ineq and M eq)

%!! NOTE: below goodness-of-fit measures interpreted in difference form ("slacks"), 
%     i.e. LHS-RHS for IR and NBP constraints if LHS>RHS
%     interpretation: required income reduction for exit option to achieve stability (individual rationality and no blocking pairs)
%     Reason for difference and not ratio:  no natural interpretation in ratio form
      
%% PART 1: construction of A, b, Aeq and beq

% restrictions (1), profit efficiency conditions for all households (matched couples)
A=zeros(M*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M);
b=zeros(M*M,1);
Aeq=zeros(M,M*M*4+M+8*M+M*M+2*M+M+M*M+M);
beq=zeros(M,1);

% we impose that maximum profit equals zero (because of CRS)

rownumber = 1; %initialize first row
    
    for i=1:M %we use prices of household i...
            for j=1:M % ... which we apply to quantities of all households j
                    %LHS
                    A(rownumber,4*M*M+i) = -1*land(j); % for land
                    A(rownumber,4*M*M+M+(i-1)*8+1) = -1*domlab1(j); % for domestic labor of male
                    A(rownumber,4*M*M+M+(i-1)*8+2) = -1*domlab2(j); % for domestic labor of male
                    A(rownumber,M*M*4+M+8*M+M*M+2*M+M+(i-1)*M+j) = -1; % for deviational variable
                    %RHS
                    b(rownumber,1) = -output(j)+other_input(j); % revenue - exp other input
                    %jump to next row
                    rownumber=rownumber+1;
            end
    end
            
rownumber = 1; %initialize first row
    
    for i=1:M                     
            %... while imposing that maximum profit (for household i) equals zero (because of CRS)
                %LHS
                Aeq(rownumber,4*M*M+i) = -1*land(i); % for land
                Aeq(rownumber,4*M*M+M+(i-1)*8+1) = -1*domlab1(i); % for domestic labor of male
                Aeq(rownumber,4*M*M+M+(i-1)*8+2) = -1*domlab2(i); % for domestic labor of male
                Aeq(rownumber,M*M*4+M+8*M+M*M+2*M+i) = 1; % for deviational variable pi-
                Aeq(rownumber,M*M*4+M+8*M+M*M+2*M+M+M*M+i) = -1; % for deviational variable pi+
                %RHS
                beq(rownumber,1) = -output(i)+other_input(i); % revenue - exp other input
                %jump to next row
                rownumber=rownumber+1;
    end        

% restriction (2) for all private ((only) matched couples) and public goods (all potential pairs): adding up constraints
startrowAeq=size(Aeq,1);
startrowbeq=size(beq,1);
Aeq=[Aeq;zeros(2*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
beq=[beq;zeros(2*M,1)];
    
rownumber=1; % initialize first row
    
    for i=1:M % for each household
        %individual private quantities: add up to observed household quantities
          %LHS
          Aeq(startrowAeq+rownumber,(i-1)*M*2+(i-1)*2+1)=1; %private quantity of male
          Aeq(startrowAeq+rownumber,(i-1)*M*2+(i-1)*2+2)=1; %private quantity of female
          %RHS
          beq(startrowbeq+rownumber,1)=qpriv(i); 
          %jump to next row
          rownumber=rownumber+1;                                     
          
        %individual public (Lindahl) prices: add up to observed household prices
          for j=1:M %for all possible females j coupled with male i
          %LHS
          Aeq(startrowAeq+rownumber,M*M*2+(i-1)*M*2+(j-1)*2+1)=1; %public price of male
          Aeq(startrowAeq+rownumber,M*M*2+(i-1)*M*2+(j-1)*2+2)=1; %public price of female
          %RHS
          beq(startrowbeq+rownumber,1)=1; % (Hicksian)public good has price 1
          %jump to next row
          rownumber=rownumber+1;                                     
          end
    end

% restriction (3) (only) for matched couples, individual rationality constraints
startrowA=size(A,1);
startrowb=size(b,1);
A=[A;zeros(2*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
b=[b;zeros(2*M,1)];
    
rownumber=1; % initialize first row
    
    for i=1:M % for each household
       %individual rationality constraint of male (member 1)
          %LHS
          A(startrowA+rownumber,(i-1)*M*2+(i-1)*2+1)=-1; %(hicksian) private quantity of male in marriage (with price = 1)
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+1)=T_male-leisure1(i); %time available of male as single minus leisure of male under marriage (evaluated at endogenously defined wage)
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+3)=1; %land income of male
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+5)=1; %(residual) nonlabor income of male
          %RHS
          b(startrowb+rownumber,1)=Q(i); %public quantity under marriage (with price = 1)
          %goodness-of-fit value ("income slack": if LHS exceeds RHS, then gives difference between LHS and RHS)
          A(startrowA+rownumber,M*M*4+M+8*M+M*M+i)=-1; %required reduction in single male's income to meet individual rationality
          %jump to next row
          rownumber=rownumber+1;                                     

                 
        %individual rationality constraint of female (member 2)
          %LHS
          A(startrowA+rownumber,(i-1)*M*2+(i-1)*2+2)=-1; %(hicksian) private quantity of female in marriage (with price = 1)
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+2)=T_female-leisure2(i); %time available of female as single minus leisure of female under marriage (evaluated at endogenously defined wage)
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+4)=1; %land income of female
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+6)=1; %(residual) nonlabor income of female
          %RHS
          b(startrowb+rownumber,1)=Q(i); %public quantity under marriage (with price = 1)
          %goodness-of-fit value ("income slack": if LHS exceeds RHS, then gives difference between LHS and RHS)
          A(startrowA+rownumber,M*M*4+M+8*M+M*M+M+i)=-1; %required reduction in single female's income to meet individual rationality
          %jump to next row
          rownumber=rownumber+1;
    end
    
% restrictions (4), for all m and f who are not matched: no blocking pair
startrowA=size(A,1);
A=[A;zeros(M*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
b=[b;zeros(M*M,1)];

rownumber=1; % initialize first row
    
    % no blocking pair constraint for each pair that is not matched (i.e. potentially blocking)
    % NOTE: to ease construction, we also include potentially blocking pair
    % constraint for matched couples, but by construction these cannot be violated
    for i=1:M %for all males i
        for j=1:M %for all females j
                 %LHS
                    % private quantities under marriage
                    A(startrowA+rownumber,(i-1)*M*2+(i-1)*2+1)=-1; %(hicksian) private quantity of male in marriage (with price = 1)
                    A(startrowA+rownumber,(j-1)*M*2+(j-1)*2+2)=-1; %(hicksian) private quantity of female in marriage (with price = 1)
                    %public quantities under marriage
                    A(startrowA+rownumber,2*M*M+(i-1)*M*2+(j-1)*2+1)=-Q(i); %public quantity of male in marriage (evaluated at male Lindahl price in potentially blocking pair)
                    A(startrowA+rownumber,2*M*M+(i-1)*M*2+(j-1)*2+2)=-Q(j); %public quantity of female in marriage (evaluated at female Lindahl price in potentially blocking pair)
                    %time available of male and female minus leisure under marriage (evaluated at endogenously defined wages)
                    A(startrowA+rownumber,4*M*M+M+(i-1)*8+1)=T_male-leisure1(i);
                    A(startrowA+rownumber,4*M*M+M+(j-1)*8+2)=T_female-leisure2(j);
                    %other nonlabor income in case of divorce
                    A(startrowA+rownumber,4*M*M+M+(i-1)*8+3)=1; %land income of male
                    A(startrowA+rownumber,4*M*M+M+(i-1)*8+5)=1; %(residual) nonlabor income of male
                    A(startrowA+rownumber,4*M*M+M+(j-1)*8+4)=1; %land income of female
                    A(startrowA+rownumber,4*M*M+M+(j-1)*8+6)=1; %(residual) nonlabor income of female
                %RHS zero
                %goodness-of-fit value ("income slack": if LHS exceeds RHS, then gives difference between LHS and RHS)
                A(startrowA+rownumber,M*M*4+M+8*M+(i-1)*M+j)=-1; %required reduction in blocking pair's income to meet NBP constraint
                %jump to next row
                rownumber=rownumber+1;
         end
    end
    

% restrictions (5), on assignable private quantities (2 ineq restr per hh), division of land (1 eq and 2 restr ineq per hh) 
% and division of (residual) nonlabor income (1 eq restr per hh)
startrowA=size(A,1);
startrowb=size(b,1);
A=[A;zeros(4*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
b=[b;zeros(4*M,1)];

rownumber=1; % initialize first row
    
for i=1:M % for each household
    %assignable private quantities
          %LHS for male
          A(startrowA+rownumber,(i-1)*M*2+(i-1)*2+1)=-1; %(hicksian) private quantity of male in marriage
          %RHS for male
          b(startrowb+rownumber,1)=-q1(i); %private quantity of male under marriage (with price = 1)
          %jump to next row
          rownumber=rownumber+1;                                     
          
          %LHS for female
          A(startrowA+rownumber,(i-1)*M*2+(i-1)*2+2)=-1; %(hicksian) private quantity of female in marriage
          %RHS for male
          b(startrowb+rownumber,1)=-q2(i); %private quantity of female under marriage (with price = 1)
          %jump to next row
          rownumber=rownumber+1;                                     
    
      %post-divorce division of land
          %LHS for male
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+3)=-1; %land income of male post divorce
          A(startrowA+rownumber,4*M*M+i)=land_1(i); %land assignable to male
          %RHS zero
          %jump to next row
          rownumber=rownumber+1;                                     
          
          %LHS for female
          A(startrowA+rownumber,4*M*M+M+(i-1)*8+4)=-1; %land income of female post divorce
          A(startrowA+rownumber,4*M*M+i)=land_2(i); %land assignable to female
          %RHS zero
          %jump to next row
          rownumber=rownumber+1;                                     
end

startrowAeq=size(Aeq,1);
startrowbeq=size(beq,1);
Aeq=[Aeq;zeros(2*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
beq=[beq;zeros(2*M,1)];

rownumber=1; %initialize first row

for i=1:M %for each household
    %post-divorce division of land: adding up constraint (male per female shares add up to total land value)
          %LHS
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+3)=-1; %land income of male post divorce
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+4)=-1; %land income of female post divorce
          Aeq(startrowAeq+rownumber,4*M*M+(i-1)+1)=land_owned(i)-other_land(i); %total land quantity post-divorce (evaluated at endogenously defined land price)
          %RHS zero
          %jump to next row
          rownumber=rownumber+1;                                     
    
    %post-divorce division of (residual) nonlabor income: total income = total expenditures
          %LHS
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+5)=1; %(residual) nonlabor income of male post divorce
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+6)=1; %(residual) nonlabor income of female post divorce
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+1)=T_male-leisure1(i); %potential labor income male minus leisure consumed (evaluated at endogenously defined wage)
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+2)=T_female-leisure2(i); %potential labor income female minus leisure consumed (evaluated at endogenously defined wage)
          Aeq(startrowAeq+rownumber,4*M*M+i)=land_owned(i); %total land quantity (evaluated at endogenously defined land price)
          %RHS
          beq(startrowbeq+rownumber,1)=Q(i)+qpriv(i); %household's public and private quantity under marriage (with price = 1)
          %jump to next row
          rownumber=rownumber+1;
     
end


% restrictions (6), define individual income shares
startrowAeq=size(Aeq,1);
Aeq=[Aeq;zeros(2*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
beq=[beq;zeros(2*M,1)];


rownumber=1; %initialize first row

 for i=1:M %for each household
      
     %male income share
          %LHS
          Aeq(startrowAeq+rownumber,(i-1)*M*2+(i-1)*2+1)=-1; %(hicksian) private quantity of male in marriage (price = 1)
          Aeq(startrowAeq+rownumber,2*M*M+(i-1)*M*2+(i-1)*2+1)=-Q(i); %public quantity in marriage (evaluated at male Lindahl price)
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+1)=-leisure1(i); %leisure consumed by male (evaluated at endogenously defined wage)
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+7)=1; %male income share
          %RHS zero
          %jump to next row
          rownumber=rownumber+1; 
    
          %female income share
          %LHS
          Aeq(startrowAeq+rownumber,(i-1)*M*2+(i-1)*2+2)=-1; %(hicksian) private quantity of female in marriage (price = 1)
          Aeq(startrowAeq+rownumber,2*M*M+(i-1)*M*2+(i-1)*2+2)=-Q(i); %public quantity in marriage (evaluated at female Lindahl price)
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+2)=-leisure2(i); %leisure consumed by female (evaluated at endogenously defined wage)
          Aeq(startrowAeq+rownumber,4*M*M+M+(i-1)*8+8)=1; %female income share
          %RHS zero
          %jump to next row
          rownumber=rownumber+1; 
 end

% restriction (7) lower and upper bound restrictions on the male and female wages
startrowA=size(A,1);
startrowb=size(b,1);
A=[A;zeros(4*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
b=[b;zeros(4*M,1)];

rownumber=1; % initialize first row
    
for i=1:M % for each household
    %lower bound
          %LHS for male
          A(startrowA+rownumber,M*M*4+M+(i-1)*8+1)=-1;
          %RHS for male
          b(startrowb+rownumber,1)=-minwagemale(i);
          %jump to next row
          rownumber=rownumber+1;                                     
          
          %LHS for female
          A(startrowA+rownumber,M*M*4+M+(i-1)*8+2)=-1;
          %RHS for female
          b(startrowb+rownumber,1)=-minwagefemale(i);
          %jump to next row
          rownumber=rownumber+1;                                     
          
    %upper bound
          %LHS for male
          A(startrowA+rownumber,M*M*4+M+(i-1)*8+1)=1;
          %RHS for male
          b(startrowb+rownumber,1)=maxwagemale(i);
          %jump to next row
          rownumber=rownumber+1;                                     
          
          %LHS for female
          A(startrowA+rownumber,M*M*4+M+(i-1)*8+2)=1;
          %RHS for male
          b(startrowb+rownumber,1)=maxwagefemale(i);
          %jump to next row
          rownumber=rownumber+1;                                                                          
end

% restriction (8) lower and upper bound restrictions on land prices
startrowA=size(A,1);
startrowb=size(b,1);
A=[A;zeros(2*M,M*M*4+M+8*M+M*M+2*M+M+M*M+M)];
b=[b;zeros(2*M,1)];

rownumber=1; % initialize first row
    
for i=1:M % for each household
    %lower bound
          %LHS
          A(startrowA+rownumber,M*M*4+i)=-1;
          %RHS
          b(startrowb+rownumber,1)=-minpriceland(i);
          %jump to next row
          rownumber=rownumber+1;                                     
          
    %upper bound
          %LHS
          A(startrowA+rownumber,M*M*4+i)=1;
          %RHS for male
          b(startrowb+rownumber,1)=maxpriceland(i);
          %jump to next row
          rownumber=rownumber+1;                                     
          
          %LHS for female
          A(startrowA+rownumber,M*M*4+M+(i-1)*8+2)=1;
          %RHS for male
          b(startrowb+rownumber,1)=maxwagefemale(i);
          %jump to next row
          rownumber=rownumber+1;                                                                          
end
 
 %% objective coeffient f (minimized)
 
 %initial LP values
 %options=optimset('LargeScale','off');
 options.Algorithm = 'dual-simplex';
 lb=zeros(size(A,2),1);
 for i=1:M                     
%        lb(M*M*4+M+(i-1)*8+5:M*M*4+M+(i-1)*8+6,1) = -10000000000; % if negative (residual) post divorce nonlabor income is possible
 end 

 
 %objective minimize aggregate of total income reduction of exit options
 %and profit inefficiency required to obtain consistency with restrictions
    
    %weight of stability restrictioins
    weightstability=1;
    
    %weight of profit efficiency conditions
    %weightprofit=100;
    
    weightprofit=weight_grid(a);
    %weight (penalty) deviational variables
    weightdeviational=weight_grid(a);
    
    %specify objective function coefficients
    f=zeros(M*M*4+M+8*M+M*M+2*M+M,1);
    f(M*M*4+M+8*M+1:M*M*4+M+8*M+M*M+2*M)=weightstability*ones(M*M+2*M,1); %NBP and IR indices
    f(M*M*4+M+8*M+M*M+2*M+1:M*M*4+M+8*M+M*M+2*M+M)=weightprofit*ones(M,1); %profit efficiency indices
    f(M*M*4+M+8*M+M*M+2*M+M+1:M*M*4+M+8*M+M*M+2*M+M+M*M+M)=weightdeviational*ones(M*M+M,1); %profit efficiency indices
    
%solve linear program  
% [x, beta, Exitflag] = linprog(f,A,b,Aeq,beq,lb,[],[],options);
A_all = [A ; Aeq];
b_all = [b ; beq];
lb=zeros(1,size(A_all,2));
equalityvector=[zeros(size(A,1),1); ones(size(Aeq,1),1)];
integervector=repmat('c',size(A_all,2),1);
size(A_all)
size(integervector,1)
size(equalityvector,1)
[pass,x,opt] = solvemip_tomlabcplex(f,A_all,b_all,equalityvector,integervector);

% NBP results per couple (column1=maximum; column2=average; column3=village)
outcome_NBP_per_couple=zeros(M,3);
if M>1
for m=1:M
    aux_couple=zeros(2*(M-1),1);
    l=1;
    for w=1:M
        if m~=w
            aux_couple(l,1)=x(M*M*4+M+8*M+(m-1)*M+w,1); %male m and female w
            l=l+1;
            aux_couple(l,1)=x(M*M*4+M+8*M+(w-1)*M+m,1); %male w and female m
            l=l+1;
        end
    end 
    outcome_NBP_per_couple(m,1)=max(aux_couple);
    outcome_NBP_per_couple(m,2)=mean(aux_couple);
    outcome_NBP_per_couple(m,3)=k;
end
end

% NBP results per male and feamel (column1=maximum; column2=average; column3=village)
outcome_NBP_per_male=zeros(M,3);
outcome_NBP_per_female=zeros(M,3);
if M>1
for m=1:M
    aux_male=zeros(M-1,1);
    aux_female=zeros(M-1,1);
    l=1;
    o=1;
    for w=1:M
        if m~=w
            aux_male(l,1)=x(M*M*4+M+8*M+(m-1)*M+w,1); %male m and female w
            l=l+1;
            aux_female(o,1)=x(M*M*4+M+8*M+(w-1)*M+m,1); %male w and female m
            o=o+1;
        end
    end 
    outcome_NBP_per_male(m,1)=max(aux_male);
    outcome_NBP_per_male(m,2)=mean(aux_male);
    outcome_NBP_per_male(m,3)=k;
    outcome_NBP_per_female(m,1)=max(aux_female);
    outcome_NBP_per_female(m,2)=mean(aux_female);
    outcome_NBP_per_female(m,3)=k;
end
end

% IR results per couple (column1=male; column2=female; column3=village)
outcome_IR_per_couple=zeros(M,3);
for m=1:M
    outcome_IR_per_couple(m,1)=x(M*M*4+M+8*M+M*M+m); %male
    outcome_IR_per_couple(m,2)=x(M*M*4+M+8*M+M*M+M+m); %female
    outcome_IR_per_couple(m,3)=k;
end

% IR results per couple (column1=male; column2=female; column3=village)
outcome_Profit_per_couple=zeros(M,2);
for m=1:M
    outcome_Profit_per_couple(m,1)=x(M*M*4+M+8*M+M*M+2*M+m);
    outcome_Profit_per_couple(m,2)=k;
end


% results-all-stability and efficiency
outcome_average_stability = ones(1,M*M+2*M)*x(M*M*4+M+8*M+1:M*M*4+M+8*M+M*M+2*M)/(M*M+2*M)
outcome_NBP=x(M*M*4+M+8*M+1:M*M*4+M+8*M+M*M);
outcome_IR=x(M*M*4+M+8*M+M*M+1:M*M*4+M+8*M+M*M+2*M);
outcome_ProfitIn=x(M*M*4+M+8*M+M*M+2*M+1:M*M*4+M+8*M+M*M+2*M+M);
outcome_average_NBP= ones(1,M*M)*outcome_NBP/(M*M)
outcome_average_IR= ones(1,2*M)*outcome_IR/(2*M)
outcome_average_ProfitIn= ones(1,M)*outcome_ProfitIn/M

auxmatrix=[outcome_IR k*ones(size(outcome_IR,1),1)];
results_IR_index=[results_IR_index ; auxmatrix];
auxmatrix=[outcome_NBP k*ones(size(outcome_NBP,1),1)];
results_NBP_index=[results_NBP_index ; auxmatrix];
auxmatrix=[outcome_ProfitIn k*ones(size(outcome_ProfitIn,1),1)];
results_Profit_index=[results_Profit_index ; auxmatrix];

results_NBP_index_summary=[results_NBP_index_summary; outcome_NBP_per_couple];
results_NBP_index_male_summary=[results_NBP_index_male_summary; outcome_NBP_per_male];
results_NBP_index_female_summary=[results_NBP_index_female_summary; outcome_NBP_per_female];
results_IR_index_summary=[results_IR_index_summary; outcome_IR_per_couple];
results_Profit_index_summary=[results_Profit_index_summary; outcome_Profit_per_couple];

%results other
for i=1:M
    
    %individual wages
    outcome_wages=x(M*M*4+M+(i-1)*8+1:M*M*4+M+(i-1)*8+2)';
    auxmatrixwages=[outcome_wages k*ones(1,1)];
    results_Wages= [results_Wages ; auxmatrixwages];
    
    %land price
    outcome_land=x(M*M*4+i);
    auxmatrixland=[outcome_land k*ones(1,1)];
    results_LandPrice= [results_LandPrice ; auxmatrixland];
    
    %individual land income
    outcome_landinc=x(M*M*4+M+(i-1)*8+3:M*M*4+M+(i-1)*8+4)';
    auxmatrixlandinc=[outcome_landinc k*ones(1,1)];
    results_LandInc= [results_LandInc ; auxmatrixlandinc];
    
    %individual residual nonlabor income (rnli)
    outcome_rnli=x(M*M*4+M+(i-1)*8+5:M*M*4+M+(i-1)*8+6)';
    auxmatrixrnli=[outcome_rnli k*ones(1,1)];
    results_ResNonLabInc= [results_ResNonLabInc ; auxmatrixrnli];
    
    
    %individual income shares
    outcome_incshare=x(M*M*4+M+(i-1)*8+7:M*M*4+M+(i-1)*8+8)';
    auxmatrixincshare=[outcome_incshare k*ones(1,1)];
    results_Incomeshares= [results_Incomeshares ; auxmatrixincshare];
    
 
end

%resultpath='results - 2019 - tomlab - robustness weights';
%filename_results2=['Stability_NBP_MALAWI_village_',num2str(k),'.txt'];
%fullfilename_results2=fullfile(resultpath,filename_results2);
%dlmwrite(fullfilename_results2, outcome_NBP, 'delimiter', '\t', 'newline', 'pc');

%resultpath='results - 2019 - tomlab - robustness weights';
%filename_results3=['Stability_IR_MALAWI_village_',num2str(k),'.txt'];
%fullfilename_results3=fullfile(resultpath,filename_results3);
%dlmwrite(fullfilename_results3, outcome_IR, 'delimiter', '\t', 'newline', 'pc');

%resultpath='results - 2019 - tomlab - robustness weights';
%filename_results4=['Profit_Ineff_MALAWI_village_',num2str(k),'.txt'];
%fullfilename_results4=fullfile(resultpath,filename_results3);
%dlmwrite(fullfilename_results4, outcome_ProfitIn, 'delimiter', '\t', 'newline', 'pc');


resultpath='results - 2019 - tomlab - robustness weights';
filename_results5=['ALL_Stability_IR_all_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results5=fullfile(resultpath,filename_results5);
dlmwrite(fullfilename_results5, results_IR_index, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results6=['ALL_Stability_NBP_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results6=fullfile(resultpath,filename_results6);
dlmwrite(fullfilename_results6, results_NBP_index, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results7=['ALL_Profit_ineff_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results7=fullfile(resultpath,filename_results7);
dlmwrite(fullfilename_results7, results_Profit_index, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results8=['ALL_Stability_NBP_summary_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results8=fullfile(resultpath,filename_results8);
dlmwrite(fullfilename_results8, results_NBP_index_summary, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results8M=['ALL_Stability_NBP_male_summary_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results8M=fullfile(resultpath,filename_results8M);
dlmwrite(fullfilename_results8M, results_NBP_index_male_summary, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results8F=['ALL_Stability_NBP_female_summary_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results8F=fullfile(resultpath,filename_results8F);
dlmwrite(fullfilename_results8F, results_NBP_index_female_summary, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results9=['ALL_Stability_IR_summary_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results9=fullfile(resultpath,filename_results9);
dlmwrite(fullfilename_results9, results_IR_index_summary, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results10=['ALL_Profit_Ineff_summary_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results9=fullfile(resultpath,filename_results10);
dlmwrite(fullfilename_results9, results_Profit_index_summary, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results11=['ALL_Wages_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results11=fullfile(resultpath,filename_results11);
dlmwrite(fullfilename_results11, results_Wages, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results12=['ALL_LandPrice_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results12=fullfile(resultpath,filename_results12);
dlmwrite(fullfilename_results12, results_LandPrice, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results13=['ALL_LandInc_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results13=fullfile(resultpath,filename_results13);
dlmwrite(fullfilename_results13, results_LandInc, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results14=['ALL_ResNonLabInc_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results14=fullfile(resultpath,filename_results14);
dlmwrite(fullfilename_results14, results_ResNonLabInc, 'delimiter', '\t', 'newline', 'pc');

resultpath='results - 2019 - tomlab - robustness weights';
filename_results15=['ALL_IncomeShares_MALAWI_weight_' num2str(weightdeviational) '.txt'];
fullfilename_results15=fullfile(resultpath,filename_results15);
dlmwrite(fullfilename_results15, results_Incomeshares, 'delimiter', '\t', 'newline', 'pc');

end % end analysis per village k
end % end sensitivity analysis weights