function [passmip,x,fmin]=solvemip_tomlabcplex(f,LHS,RHS,equalityvector,integervector,lb,ub,timelimit)
% Solve an MIP with Tomlab CPLEX (=some variables integer, some continuous)
% for LP: use solvelp_linprog or solvelp_tomlabcplex; 
% for BIP: use solvebip_tomlabcplex
%
% Use this routine for solving MIP's of following form with CPLEX:
% Min f'x
% s.t. LHS*x <= RHS
% with following special features:
% 1) integervector: is a vector with length equal to the nr of variables (x'es).
% It contains a 'b' for each binary variable, an 'i' for each integer
% variable, and a 'c' for each continuous variable.
% 2) equalityvector is a vector of zeros and ones with length equal to the
% number of constraints (i.e., nr of rows of LHS); containing a 1 if the
% corresponding constraint is an equality and a 0 if not.

nrvars = size(LHS,2);

% Control input arguments and assign defaults
error(nargchk(3,8,nargin))
if nargin<8, timelimit=[];
    if nargin<7, ub=Inf*ones(nrvars,1);
        if nargin<6, lb=zeros(nrvars,1);
            if nargin<5, integervector=[];
                if nargin<4, equalityvector=[]; warning('You did not provide input argument ''inequalityvector'': all constraints automatically treated as INequalities!')
                end
            end
        end
    end
end

if isempty(lb)
    lb=zeros(nrvars,1);
end
if isempty(ub)
    ub=Inf*ones(nrvars,1);
end

allrownrs=(1:size(LHS,1))';
equalityrownrs=setdiff((equalityvector.*allrownrs),0);

A=LHS;
b_U=RHS;
b_L=-Inf*ones(size(b_U,1),1);
b_L(equalityrownrs,1)=b_U(equalityrownrs,1);

x_L=lb;
x_U=ub;

IntVars=zeros(nrvars,1);
if ~(isempty(integervector)||all(integervector==0))
    for ii=1:nrvars
        inttype=integervector(ii,1);
        if strcmp('b',inttype)||strcmp('i',inttype)
            IntVars(ii,1)=1;
            if strcmp('b',inttype)
                x_U(ii,1)=1;
            end
        end
    end
end

if ~isempty(timelimit)
    cpxControl.TILIM=timelimit
end
Prob = mipAssign(f,A,b_L,b_U,x_L,x_U,[],[],[],[],IntVars,...
    [],[],[],[],[],[],[],[],[]);
if ~isempty(timelimit)
    cpxControl.TILIM=timelimit
end
Prob = ProbCheck(Prob, 'cplex');
if ~isempty(timelimit)
    cpxControl.TILIM=timelimit
end
Result = tomRun('cplex', Prob, 0); % see TOMLAB CPLEX USER GUIDE p 22
[ExitText,ExitFlag] = cplexStatus(Result.Inform);
ExitText;
ExitFlag;


% ExitFlag codes: see TOMLAB CPLEX USER GUIDE p 27
if ismember(Result.Inform,[101 102 105 107 109 111 113 116]) %Household behavior is collectively rationalizable
    passmip=1; 
elseif ismember(Result.Inform,[103 119]) %Household behavior is not collectively rationalizable
    passmip=0; 
elseif ismember(Result.Inform,[30 31 32 33 34 35 36 37 38 104 106 108 110 112 114 115 117 118]) %No answer for household
    passmip=2; 
else
%    error('Tomlab solver gives unexpected ExitFlag %g!',Result.Exitflag)
end

x=Result.x_k;
fmin=Result.f_k;